package Runops::Resume;

use strict;
use warnings;

our $VERSION = '0.10';

use base 'DynaLoader';
use base 'Exporter';

use vars '@EXPORT';
@EXPORT = '&resume';

Runops::Resume->bootstrap( $VERSION );

__END__

=head1 NAME

Runops::Resume - provides resumable exceptions in Perl (with some caveats)

=head1 SYNOPSIS

	use Runops::Resume;

	my $fh;
	my $file = 'some_file';
	eval
	{
		while ($file)
		{
			die unless open( $fh, $file );
		}
	};

	if ($@)
	{
		$file = shift @files;
		resume();
	}

	# use $fh

=head1 DESCRIPTION

This module provides an implementation of resumable exceptions.  That is,
whenever you encounter an exception, you can catch it, fix it, and, if you
like, C<resume()> from the point just after you threw the exception.

Of course, having left the lexical scope, any lexicals declared I<within> the
C<eval> block are now out of scope, so be careful.

This code is also pretty funky, doing scary things inside.  If this bothers
you, note that the version number is very clearly below 1.0 and tread
carefully.

=head1 BUGS

I already warned you about the use of lexicals declared I<inside> the block and
potential weird behavior.  However, if you run into anything, please let me
know.

=head1 AUTHOR

Written by chromatic, based on L<Runops::Switch> by Rafael Garcia-Suarez.

This program is free software; you may redistribute it and/or modify it under
the same terms as Perl 5.8.x itself.

=cut
